SWDEV-470698 - fix formatting, add format check workflow (#657)

This commit is contained in:
Danylo Lytovchenko
2025-08-20 16:28:06 +02:00
committed by GitHub
parent 5840940caa
commit f7338717ae
1574 changed files with 162972 additions and 199346 deletions
@@ -18,7 +18,7 @@ THE SOFTWARE.
*/
#include <hip/hip_runtime.h>
__global__ void kerAdd(int *in_a, int *in_b, int *out_c, int nelem) {
__global__ void kerAdd(int* in_a, int* in_b, int* out_c, int nelem) {
int id = blockIdx.x * blockDim.x + threadIdx.x;
if (id >= nelem) {
return;